<?php

namespace Bixo\Campaign\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Campaign\Http\Requests\CampaignDatabaseRequest;
use Bixo\Campaign\Interfaces\CampaignDatabaseRepositoryInterface;
use Bixo\Campaign\Models\CampaignDatabase;
use Bixo\Campaign\Forms\CampaignDatabase as Form;

/**
 * APIController  class for campaign_database.
 */
class CampaignDatabaseAPIController extends BaseController
{

    /**
     * Initialize campaign_database resource controller.
     *
     * @param type CampaignDatabaseRepositoryInterface $campaign_database
     *
     * @return null
     */
    public function __construct(CampaignDatabaseRepositoryInterface $campaign_database)
    {
        parent::__construct();
        $this->repository = $campaign_database;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Campaign\Repositories\Criteria\CampaignDatabaseResourceCriteria::class);
    }

    /**
     * Display a list of campaign_database.
     *
     * @return Response
     */
    public function index(CampaignDatabaseRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Campaign\Repositories\Presenter\CampaignDatabasePresenter::class)
            ->paginate();
    }

    /**
     * Display campaign_database.
     *
     * @param Request $request
     * @param Model   $campaign_database
     *
     * @return Response
     */
    public function show(CampaignDatabaseRequest $request, CampaignDatabase $campaign_database)
    {
        return $campaign_database->setPresenter(\Bixo\Campaign\Repositories\Presenter\CampaignDatabaseListPresenter::class);
        ;
    }

    /**
     * Create new campaign_database.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CampaignDatabaseRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('campaign::campaign_database.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('campaign/campaign_database/' . $campaign_database->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('campaign/campaign_database');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the campaign_database.
     *
     * @param Request $request
     * @param Model   $campaign_database
     *
     * @return Response
     */
    public function update(CampaignDatabaseRequest $request, CampaignDatabase $campaign_database)
    {
        try {
            $data = $request->all();

            $campaign_database->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('campaign::campaign_database.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('campaign/campaign_database/' . $campaign_database->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('campaign/campaign_database/' . $campaign_database->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the campaign_database.
     *
     * @param Model   $campaign_database
     *
     * @return Response
     */
    public function destroy(CampaignDatabaseRequest $request, CampaignDatabase $campaign_database)
    {
        try {
            $campaign_database->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('campaign::campaign_database.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('campaign/campaign_database/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('campaign/campaign_database/' . $campaign_database->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
