<?php

namespace Bixo\Campaign\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Campaign\Models\CampaignCall;

class CampaignCallPolicy
{

    /**
     * Determine if the given user can view the campaign_call.
     *
     * @param UserPolicy $user
     * @param CampaignCall $campaign_call
     *
     * @return bool
     */
    public function view(UserPolicy $user, CampaignCall $campaign_call)
    {
        if ($user->canDo('campaign.campaign_call.view') && $user->isAdmin()) {
            return true;
        }

        return $campaign_call->user_id == user_id() && $campaign_call->user_type == user_type();
    }

    /**
     * Determine if the given user can create a campaign_call.
     *
     * @param UserPolicy $user
     * @param CampaignCall $campaign_call
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('campaign.campaign_call.create');
    }

    /**
     * Determine if the given user can update the given campaign_call.
     *
     * @param UserPolicy $user
     * @param CampaignCall $campaign_call
     *
     * @return bool
     */
    public function update(UserPolicy $user, CampaignCall $campaign_call)
    {
        if ($user->canDo('campaign.campaign_call.edit') && $user->isAdmin()) {
            return true;
        }

        return $campaign_call->user_id == user_id() && $campaign_call->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given campaign_call.
     *
     * @param UserPolicy $user
     * @param CampaignCall $campaign_call
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CampaignCall $campaign_call)
    {
        return $campaign_call->user_id == user_id() && $campaign_call->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given campaign_call.
     *
     * @param UserPolicy $user
     * @param CampaignCall $campaign_call
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CampaignCall $campaign_call)
    {
        if ($user->canDo('campaign.campaign_call.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given campaign_call.
     *
     * @param UserPolicy $user
     * @param CampaignCall $campaign_call
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CampaignCall $campaign_call)
    {
        if ($user->canDo('campaign.campaign_call.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
