<?php

namespace Bixo\Campaign\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Campaign\Models\CampaignDatabase;

class CampaignDatabasePolicy
{

    /**
     * Determine if the given user can view the campaign_database.
     *
     * @param UserPolicy $user
     * @param CampaignDatabase $campaign_database
     *
     * @return bool
     */
    public function view(UserPolicy $user, CampaignDatabase $campaign_database)
    {
        if ($user->canDo('campaign.campaign_database.view') && $user->isAdmin()) {
            return true;
        }

        return $campaign_database->user_id == user_id() && $campaign_database->user_type == user_type();
    }

    /**
     * Determine if the given user can create a campaign_database.
     *
     * @param UserPolicy $user
     * @param CampaignDatabase $campaign_database
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('campaign.campaign_database.create');
    }

    /**
     * Determine if the given user can update the given campaign_database.
     *
     * @param UserPolicy $user
     * @param CampaignDatabase $campaign_database
     *
     * @return bool
     */
    public function update(UserPolicy $user, CampaignDatabase $campaign_database)
    {
        if ($user->canDo('campaign.campaign_database.edit') && $user->isAdmin()) {
            return true;
        }

        return $campaign_database->user_id == user_id() && $campaign_database->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given campaign_database.
     *
     * @param UserPolicy $user
     * @param CampaignDatabase $campaign_database
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CampaignDatabase $campaign_database)
    {
        return $campaign_database->user_id == user_id() && $campaign_database->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given campaign_database.
     *
     * @param UserPolicy $user
     * @param CampaignDatabase $campaign_database
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CampaignDatabase $campaign_database)
    {
        if ($user->canDo('campaign.campaign_database.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given campaign_database.
     *
     * @param UserPolicy $user
     * @param CampaignDatabase $campaign_database
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CampaignDatabase $campaign_database)
    {
        if ($user->canDo('campaign.campaign_database.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
